@@ -8,7 +8,7 @@ from transformers import BertModel, BertTokenizerFast
 from .model import GlobalPointer
 from .utils import rematch
 
-__all__=['load_NNER','GlobalPointerNet']
+__all__=['load_NNER']
 
 
 class _CustomDataset4test(Dataset):
@@ -122,7 +122,7 @@ class _NamedEntityRecognizer(object):
 
 _id2c = {0: 'dis', 1: 'sym', 2: 'pro', 3: 'equ', 4: 'dru', 5: 'ite', 6: 'bod', 7: 'dep', 8: 'mic'}
 
-def load_NNER(model_save_path='./checkpoint/macbert-large', 
+def load_NNER(model_save_path='./checkpoint/68.2796_macbert_large/macbert-large', 
                 maxlen=512, c_size=9, id2c=_id2c):
     '''
     Args:
@@ -212,9 +212,6 @@ def infer(in_file, out_file='./CMeEE_test_answer.json',
 
 
 if __name__ == '__main__':
-    model_name = 'hfl/chinese-macbert-large'
-    model = GlobalPointerNet(model_name)
-
     in_file = '../CMeEE_test.json'
     #infer(in_file)
 
